Crate tuono_lib_macros

Crate tuono_lib_macros 

Tuono

Tuono is a full-stack web framework for building React applications using Rust as the backend with a strong focus on usability and performance.

You can find the full documentation at tuono.dev

Attribute Macros

api
handler

Derive Macros

Type
Automatically generate typescript’s types from Rust’s structs, types and enums.